==> haskell-vault-0.3.0.5-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-vault/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vault
version: 0.3.0.5
id: vault-0.3.0.5-120c06b68c7b54723ea533fbac9dc558
key: vault_7HE6ievAJ7B5qT4vOKHLAS
license: BSD3
copyright: (c) Heinrich Apfelmus 2011-2013
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
homepage: https://github.com/HeinrichApfelmus/vault
synopsis: a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.
    .
    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.
    .
    Also provided is a /locker/ type, representing a store for a single element.
category: Data
author: Heinrich Apfelmus, Elliott Hird
exposed: True
exposed-modules:
    Data.Vault.Lazy Data.Vault.Strict Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Unique.Really
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/vault-0.3.0.5
library-dirs: /usr/lib/ghc-7.10.3/site-local/vault-0.3.0.5
data-dir: /usr/share/arm-linux-ghc-7.10.3/vault-0.3.0.5
hs-libraries: HSvault-0.3.0.5-7HE6ievAJ7B5qT4vOKHLAS
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    hashable-1.2.4.0-44b2533f61c94bc76cb2b27e15566721
    unordered-containers-0.2.6.0-08e36bb27daebf8e082345cc5a0772e7
haddock-interfaces: /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html: /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vault-0.3.0.5-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-vault/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vault
version: 0.3.0.5
id: vault-0.3.0.5-102b362b61d24705a338afb76b200480
key: vault_3zyMoVn9cRoFibzDYkCcGU
license: BSD3
copyright: (c) Heinrich Apfelmus 2011-2013
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
homepage: https://github.com/HeinrichApfelmus/vault
synopsis: a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.
    .
    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.
    .
    Also provided is a /locker/ type, representing a store for a single element.
category: Data
author: Heinrich Apfelmus, Elliott Hird
exposed: True
exposed-modules:
    Data.Vault.Lazy Data.Vault.Strict Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Unique.Really
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/vault-0.3.0.5
library-dirs: /usr/lib/ghc-7.10.3/site-local/vault-0.3.0.5
data-dir: /usr/share/arm-linux-ghc-7.10.3/vault-0.3.0.5
hs-libraries: HSvault-0.3.0.5-3zyMoVn9cRoFibzDYkCcGU
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
haddock-interfaces: /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html: /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
